# __monostate__
Lightweight python package free of any third-party dependencies, providing monostate base class through implementation of the borg pattern


[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)
[![MIT License](https://img.shields.io/apm/l/atomic-design-ui.svg?)](https://github.com/tterb/atomic-design-ui/blob/master/LICENSEs)

## Download
```
pip install monostate
```

## Author
Janek Zangenberg

## License
[MIT](LICENSE)
